@@ -5,21 +5,6 @@ class HomePage(BasePage):
 
     def get_poc_list(self, query="vultype=2", reload_pocs=False,
                      order_by={"vul_nums": "desc", "level": "desc", "host_nums": "desc"}, page=1, size=3000):
-        """
-        获取POC列表信息
-        :param query: 查询条件，默认为"vultype=2"
-        :type query: str
-        :param reload_pocs: 是否重新加载POC，默认为False
-        :type reload_pocs: bool
-        :param order_by: 排序字段，默认为{"vul_nums": "desc", "level": "desc", "host_nums": "desc"}，可选值为"vul_nums"、"level"和"host_nums"
-        :type order_by: dict
-        :param page: 当前页码，默认为1
-        :type page: int
-        :param size: 每页显示的记录数，默认为3000
-        :type size: int
-        :return: 返回POC列表信息的JSON对象
-        :rtype: dict
-        """
         data = {
             "query": query,
             "options": {
